# ColorCamp
___________
|  |  | 
| --- | --- |
| Testing | [![CI - Test](https://github.com/DrAthanas/ColorCamp/actions/workflows/python-package.yml/badge.svg)](https://github.com/pandas-dev/pandas/actions/workflows/unit-tests.yml) [![codecov](https://codecov.io/gh/DrAthanas/ColorCamp/coverage.svg?branch=main)](https://codecov.io/gh/DrAthanas/ColorCamp) |
| Package | [![PyPI Latest Release](https://img.shields.io/pypi/v/colorcamp.svg)](https://pypi.org/project/colorcamp/) |
| Meta | [![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://github.com/DrAthanas/ColorCamp/blob/main/LICENSE)|

The strategic use of color in branding, marketing, and data analytics is a powerful tool that elicits emotions and simplifies comprehension of complex information. Color choice influences how audiences feel about your message, and it can make intricate data more accessible. ColorCamp is a clean way of dealing with colors, palettes, mappings, and scales, and by storing human readable metadata allow more cohesive color choices.  

> A group of geese is a gaggle, an assembly of musicians is a band, a collective of lions is a pride. This package introduces that a collection of colors is a camp! Welcome to Color Camp!

## Core tenets
* Provide additional context to colors so they can be used to convey consistent information
* The colors should be immediately recognized by other applications (e.g. a string, tuple, or dictionary) without additional calls
* Easy to import/export to and from multiple sources and frameworks
* Be as lightweight and portable as possible with minimal to no dependencies 

## Installation
The source code is currently hosted on GitHub at:
https://github.com/DrAthanas/ColorCamp

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/colorcamp).

```sh
# from PyPI
pip install colorcamp
```

## Dependencies
python ^3.9, that's it!


